Installation
============


PyPI
----

sagbescheid is available on the Python Package Index. This makes installing
it with `pip <http://www.pip-installer.org>`_ as easy as::

    pip install sagbescheid

Git
---

If you want the latest code or even feel like contributing, the code is
available on `Github <https://github.com/mineo/sagbescheid>`_.

You can easily clone the code with git::

    git clone git://github.com/mineo/sagbescheid.git

Now you can start hacking on the code or install it system-wide::

    python2 setup.py install
